Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(369)

Unified Diff: crypto/openssl_util.cc

Issue 1739403002: Cut down on usage of deprecated APIs in //crypto. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: grumble grumble string vector char uint8_t grumble Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « crypto/ec_signature_creator_openssl.cc ('k') | crypto/rsa_private_key_openssl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: crypto/openssl_util.cc
diff --git a/crypto/openssl_util.cc b/crypto/openssl_util.cc
index 410cab5a88872ef4e47f11b9d227cec0a180a224..e2b859e4b3cda2c77679fdebf926c194b4a33735 100644
--- a/crypto/openssl_util.cc
+++ b/crypto/openssl_util.cc
@@ -5,8 +5,8 @@
#include "crypto/openssl_util.h"
#include <openssl/err.h>
-#include <openssl/ssl.h>
#include <openssl/cpu.h>
+#include <openssl/crypto.h>
#include <stddef.h>
#include <stdint.h>
@@ -49,14 +49,14 @@ class OpenSSLInitSingleton {
const bool has_neon =
(android_getCpuFeatures() & ANDROID_CPU_ARM_FEATURE_NEON) != 0;
base::CPU cpu;
// CRYPTO_set_NEON_capable is called before |SSL_library_init| because this
// stops BoringSSL from probing for NEON support via SIGILL in the case that
// getauxval isn't present. Also workaround a CPU with broken NEON
// support. See https://code.google.com/p/chromium/issues/detail?id=341598
CRYPTO_set_NEON_capable(has_neon && !cpu.has_broken_neon());
#endif
- SSL_library_init();
+ CRYPTO_library_init();
}
~OpenSSLInitSingleton() {}
« no previous file with comments | « crypto/ec_signature_creator_openssl.cc ('k') | crypto/rsa_private_key_openssl.cc » ('j') | no next file with comments »
@@ -49,14 +49,14 @@ class OpenSSLInitSingleton {
(android_getCpuFeatures() & ANDROID_CPU_ARM_FEATURE_NEON) != 0;
base::CPU cpu;
- // CRYPTO_set_NEON_capable is called before |SSL_library_init| because this
- // stops BoringSSL from probing for NEON support via SIGILL in the case that
- // getauxval isn't present. Also workaround a CPU with broken NEON
+ // CRYPTO_set_NEON_capable is called before |CRYPTO_library_init| because
+ // this stops BoringSSL from probing for NEON support via SIGILL in the case
+ // that getauxval isn't present. Also workaround a CPU with broken NEON
// support. See https://code.google.com/p/chromium/issues/detail?id=341598
CRYPTO_set_NEON_capable(has_neon && !cpu.has_broken_neon());

Powered by Google App Engine
This is Rietveld 408576698